## pygfxd

Python bindings for [libgfxd](https://github.com/glankk/libgfxd/)

Refer to the original documentation and function docstrings for usage.

Before running the library, run `make` to build the libgfxd native code as a shared object.

Example in `test.py`, however sample data is not provided, please source some yourself.
